@@ -52,7 +52,7 @@ from .term import FORMAT_MESSAGE
 
 if TYPE_CHECKING:
     from .base import RepoVisibility
-    from typing import Optional, Iterable, List, Literal, Dict
+    from typing import Optional, Iterable, Literal
     from .control import AtomicIterable
 
 
@@ -60,16 +60,16 @@ def process_atoms(load_template: Optional[bool] = True):
     """Custom decorator which passes the object after performing some state verification
     on it."""
 
-    def state_constructor() -> Dict:
+    def state_constructor() -> dict:
         return {"template_modifications": []}
 
     def decorator(f):
         def _helper(ctx, template: Optional[str], *args, **kwargs):
             if load_template is None:
-                template_dict = None
+                template_dict = TemplateDict()
             elif load_template:
                 try:
-                    template_dict = TemplateDict(ctx.obj["proj_path"].template)
+                    template_dict = TemplateDict(source=ctx.obj["proj_path"].template)
                 except FileNotFoundError:
                     click.secho("error: not a texproject folder", err=True)
                     sys.exit(1)
@@ -246,9 +246,9 @@ def import_(
     in the texproject data directory.
     """
     for mode, names, paths in [
-        ("macro", macros, macro_paths),
-        ("citation", citations, citation_paths),
-        ("style", styles, style_paths),
+        (LinkMode.macro, macros, macro_paths),
+        (LinkMode.citation, citations, citation_paths),
+        (LinkMode.style, styles, style_paths),
     ]:
         yield NameSequenceLinker(LinkCommand.replace, mode, names)
         yield PathSequenceLinker(LinkCommand.replace, mode, paths)
@@ -355,9 +355,9 @@ def template() -> None:
 )
 @process_atoms()
 def add(
-    macros: List[str],
-    citations: List[str],
-    styles: List[str],
+    macros: list[str],
+    citations: list[str],
+    styles: list[str],
     append: bool,
 ) -> Iterable[AtomicIterable]:
     """Add entries to the template dictionary. Existing entries with the same name will
@@ -383,7 +383,7 @@ def add(
 @_link_option(LinkMode.style)
 @process_atoms()
 def remove(
-    macros: List[str], citations: List[str], styles: List[str]
+    macros: list[str], citations: list[str], styles: list[str]
 ) -> Iterable[AtomicIterable]:
     """Remove entries from the template dictionary."""
     for mode, names in [
@@ -587,9 +587,9 @@ def show(
     """
     cmd = LinkCommand.diff if diff else LinkCommand.show
     for mode, names, paths in [
-        ("macro", macros, macro_paths),
-        ("citation", citations, citation_paths),
-        ("style", styles, style_paths),
+        (LinkMode.macro, macros, macro_paths),
+        (LinkMode.citation, citations, citation_paths),
+        (LinkMode.style, styles, style_paths),
     ]:
         yield NameSequenceLinker(cmd, mode, names)
         yield PathSequenceLinker(cmd, mode, paths)
