@@ -6,9 +6,10 @@ from dataclasses import dataclass, field
 from functools import singledispatch
 from itertools import repeat
 from pathlib import Path
-import tempfile
+from tempfile import TemporaryDirectory
 from typing import Optional
 import sys
+from uuid import uuid1
 
 import click
 
@@ -16,7 +17,8 @@ from .error import AbortRunner
 from .filesystem import ProjectPath
 
 if TYPE_CHECKING:
-    from typing import Callable, Dict, Final, Iterable, Any, Tuple
+    from typing import Callable, Final, Iterable, Any
+    from .filesystem import TemplateDict
 
 
 @singledispatch
@@ -47,17 +49,25 @@ FAIL: Final = (False, lambda: RuntimeOutput(False))
 SUCCESS: Final = (True, lambda: RuntimeOutput(True))
 
 
+class TempDir:
+    def __init__(self, temp_dir_name: str):
+        self.path: Final = Path(temp_dir_name)
+
+    def provision(self) -> Path:
+        return self.path / uuid1().hex
+
+
 class CommandRunner:
     def __init__(
         self,
         proj_path: ProjectPath,
-        template_dict: Optional[Dict],
+        template_dict: TemplateDict,
         dry_run=False,
         verbose=True,
         debug=False,
     ):
         self._proj_path: Final = proj_path
-        self._template_dict: Final = template_dict if template_dict is not None else {}
+        self._template_dict: Final = template_dict
         self._dry_run = dry_run
         self._verbose = verbose
         self._debug = debug
@@ -65,12 +75,12 @@ class CommandRunner:
     def atomic_outputs(
         self,
         command_iter: Iterable[AtomicIterable],
-        state_init: Callable[[], Dict[str, Any]] = lambda: {},
-    ) -> Iterable[Tuple[bool, RuntimeClosure]]:
+        state_init: Callable[[], dict[str, Any]] = lambda: {},
+    ) -> Iterable[tuple[bool, RuntimeClosure]]:
         state = state_init()
         for at_iter in command_iter:
-            with tempfile.TemporaryDirectory() as temp_dir_str:
-                temp_dir = Path(temp_dir_str)
+            with TemporaryDirectory() as temp_dir_str:
+                temp_dir = TempDir(temp_dir_str)
                 yield from zip(
                     repeat(at_iter.abort_on_failure),
                     at_iter(self._proj_path, self._template_dict, state, temp_dir),
@@ -103,7 +113,7 @@ class CommandRunner:
     def execute(
         self,
         command_iter: Iterable[AtomicIterable],
-        state_init: Callable[[], Dict[str, str]] = lambda: {},
+        state_init: Callable[[], dict[str, str]] = lambda: {},
     ):
         try:
             outputs = [
@@ -173,6 +183,10 @@ class AtomicIterable:
         return self
 
     def __call__(
-        self, proj_path: ProjectPath, template_dict: Dict, state: Dict, temp_dir: Path
+        self,
+        proj_path: ProjectPath,
+        template_dict: TemplateDict,
+        state: dict,
+        temp_dir: TempDir,
     ) -> Iterable[RuntimeClosure]:
         raise NotImplementedError("Atomic iterable must have a registed callable!")
