@@ -5,7 +5,7 @@ from dataclasses import dataclass
 import shlex
 
 from .base import UpdateCommand, LinkMode, ExportMode
-from .control import RuntimeClosure, AtomicIterable, RuntimeOutput
+from .control import RuntimeClosure, AtomicIterable, RuntimeOutput, TempDir
 from .filesystem import JINJA_PATH, ProjectPath
 from .template import (
     JinjaTemplate,
@@ -24,17 +24,16 @@ from .utils import (
 
 if TYPE_CHECKING:
     from .filesystem import TemplateDict
-    from typing import Dict, Optional, Iterable
+    from typing import Optional, Iterable
     from pathlib import Path
 
 
 def compile_latex(
-    proj_path: ProjectPath, build_dir: Path, tex_dir: Path = None, check: bool = False
-):
-    if tex_dir is None:
-        dir = proj_path.dir
-    else:
-        dir = tex_dir
+    proj_path: ProjectPath,
+    build_dir: Path,
+    check: bool = False,
+) -> RuntimeClosure:
+    """Compile the latex files located at build_dir"""
 
     short_cmd = [
         "latexmk",
@@ -44,13 +43,8 @@ def compile_latex(
 
     def _callable():
         out = run_cmd(
-            short_cmd
-            + [
-                f"-outdir={str(build_dir)}",
-                f"-auxdir={str(build_dir)}",
-                proj_path.config.render["default_tex_name"] + ".tex",
-            ],
-            dir,
+            short_cmd + [proj_path.config.render["default_tex_name"] + ".tex"],
+            build_dir,
             check=check,
         )
         return out
@@ -58,15 +52,15 @@ def compile_latex(
     return RuntimeClosure(
         FORMAT_MESSAGE.info(
             "Compiling LaTeX file"
-            f" '{dir}/{proj_path.config.render['default_tex_name']}.tex' with command"
-            f" '{shlex.join(short_cmd)}'"
+            f" '{build_dir}/{proj_path.config.render['default_tex_name']}.tex' with"
+            f" command '{shlex.join(short_cmd)}'"
         ),
         True,
         _callable,
     )
 
 
-def copy_output(proj_path: ProjectPath, build_dir: Path, output_map: Dict[str, Path]):
+def copy_output(proj_path: ProjectPath, build_dir: Path, output_map: dict[str, Path]):
     def _callable():
         for filetype, target in output_map.items():
             try:
@@ -90,18 +84,23 @@ def copy_output(proj_path: ProjectPath, build_dir: Path, output_map: Dict[str, P
 
 @dataclass
 class LatexCompiler(AtomicIterable):
-    output_map: Optional[Dict[str, Path]]
+    output_map: Optional[dict[str, Path]]
 
     def __call__(
         self,
         proj_path: ProjectPath,
         template_dict: TemplateDict,
-        state: Dict,
-        temp_dir: Path,
+        state: dict,
+        temp_dir: TempDir,
     ) -> Iterable[RuntimeClosure]:
-        yield compile_latex(proj_path, temp_dir)
+        # copy files to a build directory and compile
+        build_dir = temp_dir.provision()
+        yield copy_directory(proj_path, proj_path.dir, build_dir)
+        yield compile_latex(proj_path, build_dir)
+
+        # copy the relevant output
         if self.output_map is not None and len(self.output_map) > 0:
-            yield copy_output(proj_path, temp_dir, output_map=self.output_map)
+            yield copy_output(proj_path, build_dir, output_map=self.output_map)
 
 
 @dataclass
@@ -114,40 +113,38 @@ class ArchiveWriter(AtomicIterable):
         self,
         proj_path: ProjectPath,
         template_dict: TemplateDict,
-        state: Dict,
-        temp_dir: Path,
+        state: dict,
+        temp_dir: TempDir,
     ) -> Iterable[RuntimeClosure]:
-        archive_dir = temp_dir / "archive"
-        build_dir = temp_dir / "latex_compile"
-        build_dir.mkdir()
+        build_dir = temp_dir.provision()
 
-        yield copy_directory(proj_path, proj_path.dir, archive_dir)
+        # must copy before ModifyArxiv
+        yield copy_directory(proj_path, proj_path.dir, build_dir)
 
         # compile the tex files to get .bbl / .pdf
         if self.fmt in (ExportMode.arxiv, ExportMode.build):
             if self.fmt == ExportMode.arxiv:
-                # must copy first to ensure additional files are also moved
-                yield from ModifyArxiv(archive_dir)(
+                yield from ModifyArxiv(build_dir)(
                     proj_path, template_dict, state, temp_dir
                 )
                 output_map = {
-                    ".bbl": archive_dir
+                    ".bbl": build_dir
                     / (proj_path.config.render["default_tex_name"] + ".bbl")
                 }
             else:
                 output_map = {
-                    ".pdf": archive_dir
+                    ".pdf": build_dir
                     / (proj_path.config.render["default_tex_name"] + ".pdf")
                 }
-            yield compile_latex(proj_path, build_dir, archive_dir, check=True)
+            yield compile_latex(proj_path, build_dir, check=True)
             yield copy_output(proj_path, build_dir, output_map)
 
         elif self.fmt == ExportMode.nohidden:
-            yield from ModifyNoHidden(archive_dir)(
+            yield from ModifyNoHidden(build_dir)(
                 proj_path, template_dict, state, temp_dir
             )
 
-        yield make_archive(archive_dir, self.output_file, self.compression)
+        yield make_archive(build_dir, self.output_file, self.compression)
 
 
 @dataclass
@@ -158,8 +155,8 @@ class ModifyArxiv(AtomicIterable):
         self,
         proj_path: ProjectPath,
         template_dict: TemplateDict,
-        state: Dict,
-        temp_dir: Path,
+        state: dict,
+        temp_dir: TempDir,
     ) -> Iterable[RuntimeClosure]:
         # rename data directory to a filename with no dots and which does not exist
         new_data_dir_name = proj_path.data_dir.name.replace(".", "")
@@ -241,8 +238,8 @@ class ModifyNoHidden(AtomicIterable):
         self,
         proj_path: ProjectPath,
         template_dict: TemplateDict,
-        state: Dict,
-        temp_dir: Path,
+        state: dict,
+        temp_dir: TempDir,
     ) -> Iterable[RuntimeClosure]:
         # rename data directory to a filename with no dots and which does not exist
         new_data_dir_name = proj_path.data_dir.name.replace(".", "")
