@@ -8,13 +8,19 @@ import subprocess
 import click
 
 from .base import NAMES, LinkMode
-from .control import RuntimeOutput, RuntimeClosure, AtomicIterable, SUCCESS, FAIL
+from .control import (
+    RuntimeOutput,
+    RuntimeClosure,
+    AtomicIterable,
+    SUCCESS,
+    FAIL,
+)
 from .error import AbortRunner
 from .term import FORMAT_MESSAGE
 
 if TYPE_CHECKING:
     from pathlib import Path
-    from typing import List, Iterable, Dict, Literal, Optional
+    from typing import Iterable, Literal, Optional
     from .filesystem import ProjectPath, TemplateDict
 
 
@@ -37,6 +43,9 @@ def rename_path(source: Path, target: Path) -> RuntimeClosure:
 def copy_directory(
     proj_path: ProjectPath, source: Path, target: Path
 ) -> RuntimeClosure:
+    """Copy directory `source` to `target, ignoring files from config.ignore_patterns.
+    """
+
     def _callable():
         try:
             shutil.copytree(
@@ -67,7 +76,7 @@ def make_archive(source_dir, target_file, compression) -> RuntimeClosure:
 
 
 def run_cmd(
-    command: List[str], working_dir: Path, check: bool = False
+    command: list[str], working_dir: Path, check: bool = False
 ) -> RuntimeOutput:
     try:
         proc = subprocess.run(command, cwd=working_dir, capture_output=True)
@@ -85,7 +94,7 @@ def run_cmd(
         raise AbortRunner(f"could not find command '{command[0]}'")
 
 
-def run_command(proj_path: ProjectPath, command: List[str]) -> RuntimeClosure:
+def run_command(proj_path: ProjectPath, command: list[str]) -> RuntimeClosure:
     def _callable():
         return run_cmd(command, proj_path.dir)
 
@@ -109,11 +118,7 @@ class FileEditor(AtomicIterable):
     config_file: Literal["local", "global", "template"]
 
     def __call__(
-        self,
-        proj_path: ProjectPath,
-        template_dict: TemplateDict,
-        state: Dict,
-        temp_dir: Path,
+        self, proj_path: ProjectPath, template_dict: TemplateDict, *_
     ) -> Iterable[RuntimeClosure]:
         match self.config_file:
             case "local":
@@ -129,7 +134,7 @@ class FileEditor(AtomicIterable):
         try:
             click.edit(filename=str(fpath))
             if self.config_file == "template":
-                template_dict.load_from_source()
+                template_dict.reload()
             yield RuntimeClosure(FORMAT_MESSAGE.edit(fpath), *SUCCESS)
         except click.UsageError:
             yield RuntimeClosure(
@@ -142,7 +147,7 @@ class CleanProject(AtomicIterable):
     remove_git_files: Optional[bool] = None
 
     def __call__(
-        self, proj_path: ProjectPath, template_dict: Dict, *_
+        self, proj_path: ProjectPath, template_dict: TemplateDict, *_
     ) -> Iterable[RuntimeClosure]:
         for mode in LinkMode:
             for path, name in NAMES.existing_template_files(proj_path.data_dir, mode):
