@@ -163,10 +163,6 @@ def test_template(fs_runner):
     )
     assert len(Path(".texproject/citations/local-example.bib").read_text()) > 0
     Path(".texproject/macros/local-tikz.sty").unlink()
-    _run_cmd_seq(
-        fs_runner,
-        ["template", "refresh"],
-    )
     assert not Path(".texproject/macros/local-tikz.sty").exists()
     _run_cmd_seq(fs_runner, ["template", "remove", "--macro", "tikz"], expect_fail=True)
 
@@ -204,6 +200,25 @@ def test_clean(fs_runner):
     assert not Path(".texproject/macros/local-tikz.sty").exists()
 
 
+def test_import_strip_whitespace(fs_runner):
+    _run_cmd_seq(fs_runner, ["init", "empty"], ["import", "--citation", "main"])
+    txt = Path(".texproject/citations/local-main.bib").read_text()
+    assert txt == txt.strip()
+
+
+def test_multi_bib(fs_runner):
+    _run_cmd_seq(
+        fs_runner,
+        ["init", "empty"],
+        ["template", "add", "--citation", "main", "--citation", "fractals"],
+    )
+    assert (
+        Path(".texproject/bibinfo.tex").read_text().split("\n")[1]
+        == r"\bibliography{.texproject/citations/local-main,"
+        r" .texproject/citations/local-fractals}"
+    )
+
+
 def test_empty(fs_runner):
     _run_cmd_seq(fs_runner, ["init", "empty"])
     assert Path(".texproject/classinfo.tex").read_text() == "\\documentclass{article}\n"
